pub struct AzureCliCredentialOptions {
pub subscription: Option<String>,
pub tenant_id: Option<String>,
pub executor: Option<Arc<dyn Executor>>,
}Expand description
Options for constructing an AzureCliCredential.
Fields
subscription: Option<String>The name or ID of a subscription.
Set this to acquire tokens for an account other than the Azure CLI’s current account.
tenant_id: Option<String>Identifies the tenant the credential should authenticate in.
Defaults to the CLI’s default tenant, which is typically the home tenant of the logged in user.
executor: Option<Arc<dyn Executor>>An implementation of Executor to run commands asynchronously.
If None, one is created using new_executor; alternatively,
you can supply your own implementation using a different asynchronous runtime.