pub struct AzureDeveloperCliCredentialOptions {
pub executor: Option<Arc<dyn Executor>>,
pub tenant_id: Option<String>,
}Expand description
Options for constructing an AzureDeveloperCliCredential.
Fields
executor: Option<Arc<dyn Executor>>An implementation of Executor to run commands asynchronously.
If None, one is created using new_executor; alternatively,
you can supply your own implementation using a different asynchronous runtime.
tenant_id: Option<String>Identifies the tenant the credential should authenticate in.
Defaults to the azd environment, which is the tenant of the selected Azure subscription.