pub struct AzurePipelinesCredential(/* private fields */);Expand description
Authenticates an Azure Pipelines service connection.
Implementations
Sourceimpl AzurePipelinesCredential
impl AzurePipelinesCredential
Sourcepub fn new<T>(
tenant_id: String,
client_id: String,
service_connection_id: &str,
system_access_token: T,
options: Option<AzurePipelinesCredentialOptions>,
) -> Result<Arc<Self>>
pub fn new<T>( tenant_id: String, client_id: String, service_connection_id: &str, system_access_token: T, options: Option<AzurePipelinesCredentialOptions>, ) -> Result<Arc<Self>>
Creates a new AzurePipelinesCredential.
Arguments
tenant_id: The tenant (directory) ID of the service principal federated with the service connection.client_id: The client (application) ID of that service principal.service_connection_id: ID of the service connection to authenticate.system_access_token: Security token for the running build. See Azure Pipelines documentation for an example showing how to get this value.options: Options for configuring the credential. IfNone, the credential uses its default options.