pub struct DeveloperToolsCredential { /* private fields */ }Expand description
Authenticates through developer tools such as the Azure CLI.
It tries the following credential types, in this order, stopping when one provides a token:
DeveloperToolsCredential uses the first credential that provides a token for all subsequent token requests. It never tries the others again.
Implementations
Sourceimpl DeveloperToolsCredential
impl DeveloperToolsCredential
Sourcepub fn new(
options: Option<DeveloperToolsCredentialOptions>,
) -> Result<Arc<DeveloperToolsCredential>>
pub fn new( options: Option<DeveloperToolsCredentialOptions>, ) -> Result<Arc<DeveloperToolsCredential>>
Creates a new instance of DeveloperToolsCredential.
Arguments
options: Options for configuring the credential. IfNone, the credential uses its default options.