pub struct WorkloadIdentityCredentialOptions {
pub credential_options: ClientAssertionCredentialOptions,
pub client_id: Option<String>,
pub tenant_id: Option<String>,
pub token_file_path: Option<PathBuf>,
}Expand description
Options for constructing a new WorkloadIdentityCredential.
Fields
credential_options: ClientAssertionCredentialOptionsOptions for the ClientAssertionCredential used by the WorkloadIdentityCredential.
client_id: Option<String>Client ID of the Entra identity. Defaults to the value of the environment variable AZURE_CLIENT_ID.
tenant_id: Option<String>Tenant ID of the Entra identity. Defaults to the value of the environment variable AZURE_TENANT_ID.
token_file_path: Option<PathBuf>Path of a file containing a Kubernetes service account token. Defaults to the value of the environment
variable AZURE_FEDERATED_TOKEN_FILE.